=======
Credits
=======

This package is a collection of one implemenation of calculating intrinsic deuterium exchange rates of amide hydrogens based on a protein's primary sequence and the temperature and pH of the experiment.


PSX
---
https://github.com/Niels-Bohr-Institute-XNS-StructBiophys/PSX

 Pedersen, M. C. et al. PSX, Protein–Solvent Exchange: software for calculation of deuterium-exchange effects in small-angle neutron scattering measurements from protein coordinates. `J Appl Cryst <https://doi.org/10.1107/S1600576719012469/>`_ 52, 1427–1436 (2019).

Maintenance
-----------

* Jochem Smit <jhsmit@gmail.com> / <jochem.smit@kuleuven.be>
